import os
from pathlib import Path
import sys
import logging


# The windows tests have to use subprocesses, and it makes it easier
# if all tests are forced to have the package root as the CWD.
os.chdir(str(Path(__file__).parent.parent))
logging.basicConfig(level='DEBUG', stream=sys.stdout)


import logging
import asyncio
from aiorun import run


logging.basicConfig(level='DEBUG')


async def main():
    logging.info('Sleeping in main')
    try:
        await asyncio.sleep(50)
    finally:
        logging.info('Leaving main')


run(main())
logging.critical('Leaving fake main')


import sys
import os
import time
import signal
import subprocess as sp
import pytest


if sys.platform != 'win32':
    pytest.skip("These tests are for Windows compatibility.",
                allow_module_level=True)


def test_sig():
    """Basic SIGTERM"""
    proc = sp.Popen(
        'python tests/fake_main.py'.split(),
        stdout=sp.PIPE,
        stderr=sp.STDOUT,
        creationflags=sp.CREATE_NEW_PROCESS_GROUP
    )
    time.sleep(0.5)
    # proc.send_signal(signal.CTRL_BREAK_EVENT)
    # os.kill(proc.pid, signal.CTRL_C_EVENT)
    os.kill(proc.pid, signal.CTRL_BREAK_EVENT)
    print('Send signal')
    proc.wait(timeout=5)
    stdout = proc.stdout.read().decode()
    print(stdout)
    assert proc.returncode == 0

    expected = [
        'Entering run()',
        'Received signal: SIGBREAK',
        'Entering shutdown phase',
        'Cancelling pending tasks',
        'Closing the loop',
        'Bye!',
    ]

    assert all(phrase in stdout for phrase in expected)
